#[repr(i32)]pub enum HalType {
Unspecified = 0,
HalBit = 1,
HalFloat = 2,
HalS32 = 3,
HalU32 = 4,
HalS64 = 5,
HalU64 = 6,
HalPort = 7,
}Expand description
HAL data types
Variants
Unspecified = 0
HalBit = 1
Boolean
HalFloat = 2
Double precision float
HalS32 = 3
Signed 32-bit integer
HalU32 = 4
Unsigned 32-bit integer
HalS64 = 5
Signed 64-bit integer
HalU64 = 6
Unsigned 64-bit integer
HalPort = 7
Port type (advanced)
Implementations
Sourceimpl HalType
impl HalType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.