pub enum Command {
Show 22 variants
CreateComponent(CreateComponentCommand),
Ready(ReadyCommand),
Unready(UnreadyCommand),
ExitComponent(ExitComponentCommand),
CreatePin(CreatePinCommand),
SetPin(SetPinValueCommand),
CreateParam(CreateParamCommand),
SetParam(SetParamValueCommand),
CreateSignal(CreateSignalCommand),
SetSignal(SetSignalValueCommand),
DeleteSignal(DeleteSignalCommand),
Connect(ConnectCommand),
Disconnect(DisconnectCommand),
GetValue(GetValueCommand),
QueryPins(QueryPinsCommand),
QuerySignals(QuerySignalsCommand),
QueryParams(QueryParamsCommand),
QueryComponents(QueryComponentsCommand),
ComponentExists(ComponentExistsCommand),
ComponentReady(ComponentReadyCommand),
PinHasWriter(PinHasWriterCommand),
SetMessageLevel(SetMessageLevelCommand),
}Variants
CreateComponent(CreateComponentCommand)
Component commands
Ready(ReadyCommand)
Unready(UnreadyCommand)
ExitComponent(ExitComponentCommand)
CreatePin(CreatePinCommand)
Pin commands
SetPin(SetPinValueCommand)
CreateParam(CreateParamCommand)
Parameter commands
SetParam(SetParamValueCommand)
CreateSignal(CreateSignalCommand)
Signal commands
SetSignal(SetSignalValueCommand)
DeleteSignal(DeleteSignalCommand)
Connect(ConnectCommand)
Connection commands
Disconnect(DisconnectCommand)
GetValue(GetValueCommand)
Query commands
QueryPins(QueryPinsCommand)
QuerySignals(QuerySignalsCommand)
QueryParams(QueryParamsCommand)
QueryComponents(QueryComponentsCommand)
ComponentExists(ComponentExistsCommand)
ComponentReady(ComponentReadyCommand)
PinHasWriter(PinHasWriterCommand)
SetMessageLevel(SetMessageLevelCommand)
System commands
Implementations
Sourceimpl Command
impl Command
Sourcepub fn merge(
field: &mut Option<Command>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Command>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.