pub struct CreateParamCommand {
pub component: String,
pub name: String,
pub type: i32,
pub direction: i32,
pub initial_value: Option<HalValue>,
}Expand description
Create a new parameter
Fields
component: StringParent component name
name: StringParameter name
type: i32Data type
direction: i32Access mode
initial_value: Option<HalValue>Optional initial value
Implementations
Sourceimpl CreateParamCommand
impl CreateParamCommand
Sourcepub fn type(&self) -> HalType
pub fn type(&self) -> HalType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn direction(&self) -> ParamDirection
pub fn direction(&self) -> ParamDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: ParamDirection)
pub fn set_direction(&mut self, value: ParamDirection)
Sets direction to the provided enum value.