pub struct CreatePinCommand {
pub component: String,
pub name: String,
pub type: i32,
pub direction: i32,
pub initial_value: Option<HalValue>,
}Expand description
Create a new pin
Fields
component: StringParent component name
name: StringPin name
type: i32Data type
direction: i32Pin direction
initial_value: Option<HalValue>Optional initial value
Implementations
Sourceimpl CreatePinCommand
impl CreatePinCommand
Sourcepub fn type(&self) -> HalType
pub fn type(&self) -> HalType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn direction(&self) -> PinDirection
pub fn direction(&self) -> PinDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: PinDirection)
pub fn set_direction(&mut self, value: PinDirection)
Sets direction to the provided enum value.