pub struct HalParamInfo {
pub name: String,
pub short_name: String,
pub component: String,
pub type: i32,
pub direction: i32,
pub value: Option<HalValue>,
}Expand description
Information about a HAL parameter
Fields
name: StringFull param name (component.param)
short_name: StringParam name without component prefix
component: StringParent component name
type: i32Data type
direction: i32Access mode (RO/RW)
value: Option<HalValue>Current value
Implementations
Sourceimpl HalParamInfo
impl HalParamInfo
Sourcepub fn type(&self) -> HalType
pub fn type(&self) -> HalType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn direction(&self) -> ParamDirection
pub fn direction(&self) -> ParamDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: ParamDirection)
pub fn set_direction(&mut self, value: ParamDirection)
Sets direction to the provided enum value.