pub struct HalPinInfo {
pub name: String,
pub short_name: String,
pub component: String,
pub type: i32,
pub direction: i32,
pub value: Option<HalValue>,
pub signal: String,
pub has_writer: bool,
}Expand description
Information about a HAL pin
Fields
name: StringFull pin name (component.pin)
short_name: StringPin name without component prefix
component: StringParent component name
type: i32Data type
direction: i32Pin direction
value: Option<HalValue>Current value
signal: StringConnected signal name (empty if none)
has_writer: boolTrue if pin has a writer
Implementations
Sourceimpl HalPinInfo
impl HalPinInfo
Sourcepub fn type(&self) -> HalType
pub fn type(&self) -> HalType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn direction(&self) -> PinDirection
pub fn direction(&self) -> PinDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: PinDirection)
pub fn set_direction(&mut self, value: PinDirection)
Sets direction to the provided enum value.