pub struct SetMessageLevelCommand {
pub level: i32,
}Expand description
Set message level
Fields
level: i32New message level
Implementations
Sourceimpl SetMessageLevelCommand
impl SetMessageLevelCommand
Sourcepub fn level(&self) -> MessageLevel
pub fn level(&self) -> MessageLevel
Returns the enum value of level, or the default if the field is set to an invalid enum value.
Sourcepub fn set_level(&mut self, value: MessageLevel)
pub fn set_level(&mut self, value: MessageLevel)
Sets level to the provided enum value.