#[repr(i32)]pub enum BrakeState {
BrakeRelease = 0,
BrakeEngage = 1,
}Expand description
Brake state
Variants
Implementations
Sourceimpl BrakeState
impl BrakeState
Sourceimpl BrakeState
impl BrakeState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.