#[repr(i32)]pub enum CoolantState {
CoolantOff = 0,
CoolantOn = 1,
}Expand description
Coolant state
Variants
Implementations
Sourceimpl CoolantState
impl CoolantState
Sourceimpl CoolantState
impl CoolantState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.