#[repr(i32)]pub enum ExecState {
Unspecified = 0,
ExecError = 1,
ExecDone = 2,
ExecWaitingForMotion = 3,
ExecWaitingForMotionQueue = 4,
ExecWaitingForIo = 5,
ExecWaitingForMotionAndIo = 6,
ExecWaitingForDelay = 7,
ExecWaitingForSystemCmd = 8,
ExecWaitingForSpindleOriented = 9,
}Expand description
Execution state
Variants
Unspecified = 0
ExecError = 1
ExecDone = 2
ExecWaitingForMotion = 3
ExecWaitingForMotionQueue = 4
ExecWaitingForIo = 5
ExecWaitingForMotionAndIo = 6
ExecWaitingForDelay = 7
ExecWaitingForSystemCmd = 8
ExecWaitingForSpindleOriented = 9
Implementations
Sourceimpl ExecState
impl ExecState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.