#[repr(i32)]pub enum MotionType {
None = 0,
Traverse = 1,
Feed = 2,
Arc = 3,
Toolchange = 4,
Probing = 5,
Indexrotary = 6,
}Expand description
Motion type
Variants
Implementations
Sourceimpl MotionType
impl MotionType
Sourceimpl MotionType
impl MotionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.