#[repr(i32)]pub enum SpindleCommand {
SpindleCmdOff = 0,
SpindleCmdForward = 1,
SpindleCmdReverse = 2,
SpindleCmdIncrease = 3,
SpindleCmdDecrease = 4,
SpindleCmdConstant = 5,
}Expand description
Spindle command
Variants
SpindleCmdOff = 0
SpindleCmdForward = 1
SpindleCmdReverse = 2
SpindleCmdIncrease = 3
SpindleCmdDecrease = 4
SpindleCmdConstant = 5
Implementations
Sourceimpl SpindleCommand
impl SpindleCommand
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.