pub struct AutoCommand {
pub command: i32,
pub line: i32,
}Expand description
Auto mode command
Fields
command: i32line: i32For AUTO_RUN, starting line
Implementations
Sourceimpl AutoCommand
impl AutoCommand
Sourcepub fn command(&self) -> AutoCommandType
pub fn command(&self) -> AutoCommandType
Returns the enum value of command, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command(&mut self, value: AutoCommandType)
pub fn set_command(&mut self, value: AutoCommandType)
Sets command to the provided enum value.