pub struct BrakeCommand {
pub state: i32,
pub spindle: i32,
}Expand description
Brake command
Fields
state: i32spindle: i32Implementations
Sourceimpl BrakeCommand
impl BrakeCommand
Sourcepub fn state(&self) -> BrakeState
pub fn state(&self) -> BrakeState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: BrakeState)
pub fn set_state(&mut self, value: BrakeState)
Sets state to the provided enum value.