pub struct IoStatus {
pub estop: bool,
pub mist: i32,
pub flood: i32,
pub analog_inputs: Vec<f64>,
pub analog_outputs: Vec<f64>,
pub digital_inputs: Vec<bool>,
pub digital_outputs: Vec<bool>,
}Expand description
I/O status
Fields
estop: boolmist: i32flood: i32analog_inputs: Vec<f64>64 analog inputs
analog_outputs: Vec<f64>64 analog outputs
digital_inputs: Vec<bool>64 digital inputs
digital_outputs: Vec<bool>64 digital outputs
Implementations
Sourceimpl IoStatus
impl IoStatus
Sourcepub fn mist(&self) -> CoolantState
pub fn mist(&self) -> CoolantState
Returns the enum value of mist, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mist(&mut self, value: CoolantState)
pub fn set_mist(&mut self, value: CoolantState)
Sets mist to the provided enum value.
Sourcepub fn flood(&self) -> CoolantState
pub fn flood(&self) -> CoolantState
Returns the enum value of flood, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flood(&mut self, value: CoolantState)
pub fn set_flood(&mut self, value: CoolantState)
Sets flood to the provided enum value.