pub struct OperatorMessageCommand {
pub type: i32,
pub message: String,
}Expand description
Operator messages
Fields
type: i32message: StringImplementations
Sourceimpl OperatorMessageCommand
impl OperatorMessageCommand
Sourcepub fn type(&self) -> MessageType
pub fn type(&self) -> MessageType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: MessageType)
pub fn set_type(&mut self, value: MessageType)
Sets type to the provided enum value.