SpindleControlCommand

Struct SpindleControlCommand 

pub struct SpindleControlCommand {
    pub command: i32,
    pub speed: f64,
    pub spindle: i32,
    pub wait_for_at_speed: bool,
}
Spindle command

Fields

command: i32speed: f64

For FORWARD/REVERSE

spindle: i32

Spindle number (default 0)

wait_for_at_speed: bool

Wait for spindle to reach speed

Implementations

Source

impl SpindleControlCommand

pub fn command(&self) -> SpindleCommand

Returns the enum value of command, or the default if the field is set to an invalid enum value.

pub fn set_command(&mut self, value: SpindleCommand)

Sets command to the provided enum value.