pub struct TaskStatus {Show 22 fields
pub echo_serial_number: i32,
pub state: i32,
pub task_mode: i32,
pub task_state: i32,
pub exec_state: i32,
pub interp_state: i32,
pub call_level: i32,
pub read_line: i32,
pub motion_line: i32,
pub current_line: i32,
pub file: String,
pub command: String,
pub program_units: i32,
pub interpreter_errcode: i32,
pub optional_stop: bool,
pub block_delete: bool,
pub task_paused: i32,
pub input_timeout: bool,
pub rotation_xy: f64,
pub ini_filename: String,
pub delay_left: f64,
pub queued_mdi_commands: i32,
}Expand description
Task status information
Fields
echo_serial_number: i32state: i32task_mode: i32task_state: i32exec_state: i32interp_state: i32call_level: i32read_line: i32motion_line: i32current_line: i32file: Stringcommand: Stringprogram_units: i321=inch, 2=mm, 3=cm
interpreter_errcode: i32optional_stop: boolblock_delete: booltask_paused: i32input_timeout: boolrotation_xy: f64ini_filename: Stringdelay_left: f64queued_mdi_commands: i32Implementations
Sourceimpl TaskStatus
impl TaskStatus
Sourcepub fn state(&self) -> RcsStatus
pub fn state(&self) -> RcsStatus
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn task_mode(&self) -> TaskMode
pub fn task_mode(&self) -> TaskMode
Returns the enum value of task_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_task_mode(&mut self, value: TaskMode)
pub fn set_task_mode(&mut self, value: TaskMode)
Sets task_mode to the provided enum value.
Sourcepub fn task_state(&self) -> TaskState
pub fn task_state(&self) -> TaskState
Returns the enum value of task_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_task_state(&mut self, value: TaskState)
pub fn set_task_state(&mut self, value: TaskState)
Sets task_state to the provided enum value.
Sourcepub fn exec_state(&self) -> ExecState
pub fn exec_state(&self) -> ExecState
Returns the enum value of exec_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_exec_state(&mut self, value: ExecState)
pub fn set_exec_state(&mut self, value: ExecState)
Sets exec_state to the provided enum value.
Sourcepub fn interp_state(&self) -> InterpState
pub fn interp_state(&self) -> InterpState
Returns the enum value of interp_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_interp_state(&mut self, value: InterpState)
pub fn set_interp_state(&mut self, value: InterpState)
Sets interp_state to the provided enum value.