pub struct TrajectoryStatus {Show 31 fields
pub linear_units: f64,
pub angular_units: f64,
pub cycle_time: f64,
pub joints: i32,
pub spindles: i32,
pub axis_mask: i32,
pub motion_mode: i32,
pub enabled: bool,
pub inpos: bool,
pub queue: i32,
pub active_queue: i32,
pub queue_full: bool,
pub motion_id: i32,
pub paused: bool,
pub feedrate: f64,
pub rapidrate: f64,
pub velocity: f64,
pub acceleration: f64,
pub max_velocity: f64,
pub max_acceleration: f64,
pub probe_tripped: bool,
pub probing: bool,
pub probe_val: i32,
pub kinematics_type: i32,
pub motion_type: i32,
pub distance_to_go: f64,
pub current_vel: f64,
pub feed_override_enabled: bool,
pub adaptive_feed_enabled: bool,
pub feed_hold_enabled: bool,
pub num_extrajoints: i32,
}Expand description
Trajectory status information
Fields
linear_units: f64angular_units: f64cycle_time: f64joints: i32spindles: i32axis_mask: i32motion_mode: i32enabled: boolinpos: boolqueue: i32active_queue: i32queue_full: boolmotion_id: i32paused: boolfeedrate: f64Feed override scale (0.0-1.0+)
rapidrate: f64Rapid override scale (0.0-1.0)
velocity: f64acceleration: f64max_velocity: f64max_acceleration: f64probe_tripped: boolprobing: boolprobe_val: i32kinematics_type: i32motion_type: i32distance_to_go: f64current_vel: f64feed_override_enabled: booladaptive_feed_enabled: boolfeed_hold_enabled: boolnum_extrajoints: i32Implementations
Sourceimpl TrajectoryStatus
impl TrajectoryStatus
Sourcepub fn motion_mode(&self) -> TrajMode
pub fn motion_mode(&self) -> TrajMode
Returns the enum value of motion_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_motion_mode(&mut self, value: TrajMode)
pub fn set_motion_mode(&mut self, value: TrajMode)
Sets motion_mode to the provided enum value.
Sourcepub fn kinematics_type(&self) -> KinematicsType
pub fn kinematics_type(&self) -> KinematicsType
Returns the enum value of kinematics_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kinematics_type(&mut self, value: KinematicsType)
pub fn set_kinematics_type(&mut self, value: KinematicsType)
Sets kinematics_type to the provided enum value.
Sourcepub fn motion_type(&self) -> MotionType
pub fn motion_type(&self) -> MotionType
Returns the enum value of motion_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_motion_type(&mut self, value: MotionType)
pub fn set_motion_type(&mut self, value: MotionType)
Sets motion_type to the provided enum value.