pub struct SpindleControlCommand {
pub command: i32,
pub speed: f64,
pub spindle: i32,
pub wait_for_at_speed: bool,
}Expand description
Spindle command
Fields
command: i32speed: f64For FORWARD/REVERSE
spindle: i32Spindle number (default 0)
wait_for_at_speed: boolWait for spindle to reach speed
Implementations
Sourceimpl SpindleControlCommand
impl SpindleControlCommand
Sourcepub fn command(&self) -> SpindleCommand
pub fn command(&self) -> SpindleCommand
Returns the enum value of command, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command(&mut self, value: SpindleCommand)
pub fn set_command(&mut self, value: SpindleCommand)
Sets command to the provided enum value.